Module executor

Module executor 

Concrete execution over Falcon IL.

Structs

Driver
A driver for a concrete executor over Falcon IL.
State
A concrete State.
Successor
The result of executing an il::Operation over a State.

Enums

SuccessorType
A representation of the successor location in an il::Program after execution of an il::Operation.

Functions

eval
Evaluate an il::Expression where all terminals are il::Constant, and return the resulting il::Constant.

Type Aliases

Memory
A falcon::memory::paged::Memory over il::Constant.