PreHashAlgorithm

Enum PreHashAlgorithm 

pub enum PreHashAlgorithm {
    Sha256,
    Sha512,
}
Pre-hash algorithm selector for HashFN-DSA (FIPS 206 6.2).

The message is hashed with the chosen algorithm before signing. The algorithm OID is injected into the hash context so that sign and verify must use matching algorithms.

Variants



Sha256

SHA-256 (32-byte digest, OID 2.16.840.1.101.3.4.2.1)



Sha512

SHA-512 (64-byte digest, OID 2.16.840.1.101.3.4.2.3)